This function performs a statistical test to determine whether data should be transformed to logarithmic scale or kept in level (original scale)
Value
An object containing the log-level test results. First the AICc of the model in levels and then the AICc of the model with logs
Examples
series <- rjd3toolkit::Retail$BookStores
loglevel(series)
#> Error in rJava::.jcall("jdplus/highfreq/base/r/ExtendedAirlineProcessor", "Ljdplus/highfreq/base/api/ExtendedAirlineSpec;", "spec", rJava::.jarray(as.numeric(period)), as.integer(differencing), as.logical(ar), as.logical(to_int)): RcallMethod: cannot determine object class